# v1

Types:

```python
from isaacus.types.ilgs.v1 import (
    Crossreference,
    Date,
    Document,
    Email,
    ExternalDocument,
    IDNumber,
    Location,
    Person,
    PhoneNumber,
    Quote,
    Segment,
    Span,
    Term,
    Website,
)
```
